aboutsummaryrefslogtreecommitdiff
path: root/odb/sqlite/connection.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2015-07-15 18:43:03 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2015-07-15 18:43:03 +0200
commit0f9cfacd6cc45f78f1453a8eeb7ffa542dc5dc48 (patch)
tree76b5baf158e35988d7b14d437f1a03774e0e0742 /odb/sqlite/connection.cxx
parent27a578709046a81bb0efc0027bfc74318615447e (diff)
Implement SQLite incremental BLOB/TEXT I/O
Diffstat (limited to 'odb/sqlite/connection.cxx')
-rw-r--r--odb/sqlite/connection.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/odb/sqlite/connection.cxx b/odb/sqlite/connection.cxx
index dd30f1f..c44d648 100644
--- a/odb/sqlite/connection.cxx
+++ b/odb/sqlite/connection.cxx
@@ -33,7 +33,7 @@ namespace odb
: odb::connection (db),
db_ (db),
unlock_cond_ (unlock_mutex_),
- statements_ (0)
+ active_objects_ (0)
{
int f (db.flags () | extra_flags);
const string& n (db.name ());
@@ -86,7 +86,7 @@ namespace odb
db_ (db),
handle_ (handle),
unlock_cond_ (unlock_mutex_),
- statements_ (0)
+ active_objects_ (0)
{
init ();
}
@@ -184,11 +184,11 @@ namespace odb
void connection::
clear ()
{
// The current first statement will remove itself from the list
// and make the second statement (if any) the new first.
//
- while (statements_ != 0)
- statements_->reset ();
+ while (active_objects_ != 0)
+ active_objects_->clear ();
}
}
}
@@ -184,11 +184,11 @@ namespace odb
clear ()
{
- // The current first statement will remove itself from the list
- // and make the second statement (if any) the new first.
+ // The current first active_object will remove itself from the list
+ // and make the second object (if any) the new first.
//